@@ -1,13 +1,13 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "8.15"
-#define S7_DATE "2020-2-7"
+#define S7_VERSION "8.17"
+#define S7_DATE "2020-4-16"
 
 #include <stdint.h>           /* for int64_t */
 
-typedef int64_t s7_int;       /* This sets the size of integers in Scheme; it needs to be big enough to accomodate a C pointer. */
-typedef double s7_double;     /*   similarly for Scheme reals; only double works in C++ */
+typedef int64_t s7_int;
+typedef double s7_double;
 
 #ifndef __cplusplus
 #ifndef _MSC_VER
@@ -126,7 +126,6 @@ bool s7_history_enabled(s7_scheme *sc);
 bool s7_set_history_enabled(s7_scheme *sc, bool enabled);
 
 s7_pointer s7_gc_on(s7_scheme *sc, bool on);                         /* (gc on) */
-void s7_set_gc_stats(s7_scheme *sc, bool on);                        /* (set! (*s7* 'gc-stats) on) */
 
 s7_int s7_gc_protect(s7_scheme *sc, s7_pointer x);
 void s7_gc_unprotect_at(s7_scheme *sc, s7_int loc);
@@ -212,7 +211,6 @@ s7_pointer s7_cddddr(s7_pointer p);
 s7_pointer s7_cdddar(s7_pointer p);
 s7_pointer s7_cddaar(s7_pointer p);
 
-
 bool s7_is_list(s7_scheme *sc, s7_pointer p);                                /* (list? p) -> (or (pair? p) (null? p)) */
 bool s7_is_proper_list(s7_scheme *sc, s7_pointer p);                         /* (proper-list? p) */
 s7_int s7_list_length(s7_scheme *sc, s7_pointer a);                          /* (length a) */
@@ -228,6 +226,7 @@ s7_pointer s7_member(s7_scheme *sc, s7_pointer obj, s7_pointer lst);         /*
 s7_pointer s7_memq(s7_scheme *sc, s7_pointer obj, s7_pointer x);             /* (memq obj lst) */
 bool s7_tree_memq(s7_scheme *sc, s7_pointer sym, s7_pointer tree);           /* (tree-memq sym tree) */
 
+
 bool s7_is_string(s7_pointer p);                                             /* (string? p) */
 const char *s7_string(s7_pointer p);                                         /* Scheme string -> C string (do not free the string) */
 s7_pointer s7_make_string(s7_scheme *sc, const char *str);                   /* C string -> Scheme string (str is copied) */
@@ -385,6 +384,11 @@ s7_pointer s7_openlet(s7_scheme *sc, s7_pointer e);                         /* (
 bool s7_is_openlet(s7_pointer e);                                           /* (openlet? e) */
 s7_pointer s7_method(s7_scheme *sc, s7_pointer obj, s7_pointer method);
 
+/* *s7* */
+s7_pointer s7_let_field_ref(s7_scheme *sc, s7_pointer sym);                 /* (*s7* sym) */
+s7_pointer s7_let_field_set(s7_scheme *sc, s7_pointer sym, s7_pointer new_value); /* (set! (*s7* sym) new_value) */
+
+
 s7_pointer s7_name_to_value(s7_scheme *sc, const char *name);               /* name's value in the current environment (after turning name into a symbol) */
 s7_pointer s7_symbol_table_find_name(s7_scheme *sc, const char *name);
 s7_pointer s7_symbol_value(s7_scheme *sc, s7_pointer sym);
@@ -565,6 +569,7 @@ s7_pointer s7_typed_dilambda(s7_scheme *sc,
 
 s7_pointer s7_values(s7_scheme *sc, s7_pointer args);          /* (values ...) */
 
+
 s7_pointer s7_make_iterator(s7_scheme *sc, s7_pointer e);      /* (make-iterator e) */
 bool s7_is_iterator(s7_pointer obj);                           /* (iterator? obj) */
 bool s7_iterator_is_at_end(s7_scheme *sc, s7_pointer obj);     /* (iterator-at-end? obj) */
@@ -577,12 +582,6 @@ s7_pointer s7_fill(s7_scheme *sc, s7_pointer args);            /* (fill! ...) */
 s7_pointer s7_type_of(s7_scheme *sc, s7_pointer arg);          /* (type-of arg) */
 
 
-s7_int s7_print_length(s7_scheme *sc);                         /* value of (*s7* 'print-length) */
-s7_int s7_set_print_length(s7_scheme *sc, s7_int new_len);     /* sets (*s7* 'print-length), returns old value */
-s7_int s7_float_format_precision(s7_scheme *sc);               /* value of (*s7* 'float-format-precision) */
-s7_int s7_set_float_format_precision(s7_scheme *sc, s7_int new_len); /* sets (*s7* 'float-format-precision), returns old value */
-
-
 
 /* -------------------------------------------------------------------------------- */
 /* c types/objects */
@@ -660,9 +659,8 @@ void s7_c_type_set_setter       (s7_scheme *sc, s7_int tag, s7_pointer setter);
 /* the new clm optimizer!  this time for sure! 
  *    d=double, i=integer, v=c_object, p=s7_pointer
  *    first return type, then arg types, d_vd -> returns double takes c_object and double (i.e. a standard clm generator)
- */
-
-/* It is possible to tell s7 to call a foreign function directly, without any scheme-related
+ *
+ * It is possible to tell s7 to call a foreign function directly, without any scheme-related
  *   overhead.  The call needs to take the form of one of the s7_*_t functions in s7.h.  For example,
  *   one way to call + is to pass it two s7_double arguments and get an s7_double back.  This is the
  *   s7_d_dd_t function (the first letter gives the return type, the rest give successive argument types).
@@ -761,7 +759,6 @@ typedef s7_pointer (*s7_p_d_t)(s7_scheme *sc, s7_double x);
 void s7_set_p_d_function(s7_pointer f, s7_p_d_t df);
 s7_p_d_t s7_p_d_function(s7_pointer f);
 
-
 /* Here is an example of using these functions; more extensive examples are in clm2xen.c in sndlib, and in s7.c.
  * (This example comes from a HackerNews discussion):
  * plus.c:
@@ -861,16 +858,21 @@ typedef s7_double s7_Double;
 #define s7_make_object        s7_make_c_object
 #define s7_mark_object        s7_mark
 #define s7_UNSPECIFIED(Sc)    s7_unspecified(Sc)
-#define s7_NIL(Sc)            s7_nil(Sc)
-s7_int s7_new_type_1(s7_scheme *sc,
-		     const char *name,
-		     char *(*print)(s7_scheme *sc, void *value),
-		     void (*gc_free)(void *value),
-		     bool (*equal)(void *val1, void *val2),
-		     void (*mark)(void *val),
-		     s7_pointer (*ref)(s7_scheme *sc, s7_pointer obj, s7_pointer args), 
-		     s7_pointer (*set)(s7_scheme *sc, s7_pointer obj, s7_pointer args));
-#define s7_new_type(Name, Print, GC_Free, Equal, Mark, Ref, Set) s7_new_type_1(s7, Name, Print, GC_Free, Equal, Mark, Ref, Set)
+
+s7_int s7_print_length(s7_scheme *sc);                               /* (*s7* 'print-length) */
+s7_int s7_set_print_length(s7_scheme *sc, s7_int new_len);           /* (set! (*s7* 'print-length) new_len), but returns old value */
+s7_int s7_float_format_precision(s7_scheme *sc);                     /* (*s7* 'float-format-precision) */
+s7_int s7_set_float_format_precision(s7_scheme *sc, s7_int new_len); /* (set! (*s7* 'float-format-precision) new_len), but returns old value */
+void s7_set_gc_stats(s7_scheme *sc, bool on);                        /* (set! (*s7* 'gc-stats) on) */
+
+#else
+
+#define s7_set_gc_stats(Sc, On)                  s7_let_field_set(Sc, s7_make_symbol(Sc, "gc-stats"), On)
+#define s7_print_length(Sc)           s7_integer(s7_let_field_ref(Sc, s7_make_symbol(Sc, "print-length")))
+#define s7_float_format_precision(Sc) s7_integer(s7_let_field_ref(Sc, s7_make_symbol(Sc, "float-format-precision")))
+#define s7_set_print_length(Sc, Val)             s7_let_field_set(Sc, s7_make_symbol(Sc, "print-length"), s7_make_integer(Sc, Val))
+#define s7_set_float_format_precision(Sc, Val)   s7_let_field_set(Sc, s7_make_symbol(Sc, "float-format-precision"), s7_make_integer(Sc, Val))
+/* but the last two used to return the old value -- these return the new value */
 #endif
 
 
@@ -878,11 +880,14 @@ s7_int s7_new_type_1(s7_scheme *sc,
  * 
  *        s7 changes
  *
- * 31-Jan:    macro(*) and bacro(*) -- unnamed macros like lambda(*) for functions.
+ * 9-Mar:     move openlets to (*s7* 'openlets), s7-version to (*s7* 'version), deprecate nan.0 and inf.0.
+ * 17-Feb:    s7_let_field_ref|set for *s7* access. *function* to replace __func__.
+ *            deprecate __func__, s7_print_length, s7_float_format_precision, s7_set_gc_stats.
+ * 31-Jan:    macro(*) and bacro(*) -- unnamed macros analogous to lambda(*).
  * 20-Jan:    debug.scm and (*s7* 'debug), trace-in, dynamic-unwind.
  *            remove coverlets (openlets is now a dilambda).
  * 10-Jan:    s7_c_type_set_gc_free and s7_c_type_set_gc_mark.
- * 2-Jan:     s7_c_type_set_is_equal and s7_c_type_set_is_equivalent.
+ * 2-Jan-20:  s7_c_type_set_is_equal and s7_c_type_set_is_equivalent.
  * --------
  * 2-Nov:     s7_repl.
  * 30-Oct:    change S7_DATE format, and start updating it to reflect s7.c.
@@ -977,7 +982,7 @@ s7_int s7_new_type_1(s7_scheme *sc,
  * 16-June:   remove unoptimize and s7_unoptimize.
  * 14-May:    s7_define_safe_function_star.  Removed s7_catch_all.
  * 22-Apr:    remove s7_apply_n_10, s7_is_valid_pointer, s7_keyword_eq_p.
- * 5-Mar-14:  s7_heap_size, s7_gc_freed.
+ * 5-Mar-14:  s7_heap_size, s7_gc_freed (subsequently removed).
  * --------
  * 8-Nov:     s7_symbol_documentation, s7_define_constant_with_documentation.
  * 17-Oct:    bignum-precision (procedure-with-setter) is now an integer variable named *bignum-precision*.
