@@ -2355,5 +2355,7 @@
 ;(clear-and-gc)
 ;(*s7* 'memory-usage)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
 
