@@ -241,4 +241,6 @@
 (for-each test-hash (list 1 10 100 1000 10000 100000 1000000))
 (newline)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
